OC.L10N.register(
    "core",
    {
    "Please select a file." : "Please select a file.",
    "File is too big" : "File is too big",
    "The selected file is not an image." : "The selected file is not an image.",
    "The selected file cannot be read." : "The selected file cannot be read.",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "Invalid file provided" : "Invalid file provided",
    "No image or file provided" : "No image or file provided",
    "Unknown filetype" : "Unknown filetype",
    "An error occurred. Please contact your admin." : "An error occurred. Please contact your admin.",
    "Invalid image" : "Invalid image",
    "State token does not match" : "State token does not match",
    "Invalid app password" : "Invalid app password",
    "Could not complete login" : "Could not complete login",
    "State token missing" : "State token missing",
    "Your login token is invalid or has expired" : "Your login token is invalid or has expired",
    "Please use original client" : "Please use original client",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
    "Login" : "Login",
    "Unsupported email length (>255)" : "Unsupported email length (>255)",
    "Password reset is disabled" : "Password reset is disabled",
    "Could not reset password because the token is expired" : "Could not reset password because the token is expired",
    "Could not reset password because the token is invalid" : "Could not reset password because the token is invalid",
    "Password is too long. Maximum allowed length is 469 characters." : "Password is too long. Maximum allowed length is 469 characters.",
    "%s password reset" : "%s password reset",
    "Password reset" : "Password reset",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following button to reset your password. If you have not requested the password reset, then ignore this email.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following link to reset your password. If you have not requested the password reset, then ignore this email.",
    "Reset your password" : "Reset your password",
    "The given provider is not available" : "The given provider is not available",
    "Task not found" : "Task not found",
    "Internal error" : "Internal error",
    "Not found" : "Not found",
    "Node is locked" : "Node is locked",
    "Bad request" : "Bad request",
    "Input text is too long" : "Input text is too long",
    "Requested task type does not exist" : "Requested task type does not exist",
    "Necessary language model provider is not available" : "Necessary language model provider is not available",
    "Cannot generate more than 12 images" : "Cannot generate more than 12 images",
    "Cannot generate less than 1 image" : "Cannot generate less than 1 image",
    "No text to image provider is available" : "No text to image provider is available",
    "Image not found" : "Image not found",
    "No translation provider available" : "No translation provider available",
    "Could not detect language" : "Could not detect language",
    "Unable to translate" : "Unable to translate",
    "No valid filters provided" : "No valid filters provided",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Repair step:",
    "Repair info:" : "Repair info:",
    "Repair warning:" : "Repair warning:",
    "Repair error:" : "Repair error:",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Some of your link shares have been removed",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
    "The account limit of this instance is reached." : "The account limit of this instance is reached.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies.",
    "Learn more ↗" : "Learn more ↗",
    "Preparing update" : "Preparing update",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
    "Turned on maintenance mode" : "Turned on maintenance mode",
    "Turned off maintenance mode" : "Turned off maintenance mode",
    "Maintenance mode is kept active" : "Maintenance mode is kept active",
    "Updating database schema" : "Updating database schema",
    "Updated database" : "Updated database",
    "Update app \"%s\" from App Store" : "Update app \"%s\" from App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)",
    "Updated \"%1$s\" to %2$s" : "Updated \"%1$s\" to %2$s",
    "Set log level to debug" : "Set log level to debug",
    "Reset log level" : "Reset log level",
    "Starting code integrity check" : "Starting code integrity check",
    "Finished code integrity check" : "Finished code integrity check",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
    "Already up to date" : "Already up to date",
    "Windows Command Script" : "Windows Command Script",
    "Electronic book document" : "Electronic book document",
    "TrueType Font Collection" : "TrueType Font Collection",
    "Web Open Font Format" : "Web Open Font Format",
    "GPX geographic data" : "GPX geographic data",
    "Gzip archive" : "Gzip archive",
    "Adobe Illustrator document" : "Adobe Illustrator document",
    "Java source code" : "Java source code",
    "JavaScript source code" : "JavaScript source code",
    "JSON document" : "JSON document",
    "Microsoft Access database" : "Microsoft Access database",
    "Microsoft OneNote document" : "Microsoft OneNote document",
    "Microsoft Word document" : "Microsoft Word document",
    "Unknown" : "Unknown",
    "PDF document" : "PDF document",
    "PostScript document" : "PostScript document",
    "RSS summary" : "RSS summary",
    "Android package" : "Android package",
    "KML geographic data" : "KML geographic data",
    "KML geographic compressed data" : "KML geographic compressed data",
    "Lotus Word Pro document" : "Lotus Word Pro document",
    "Excel spreadsheet" : "Excel spreadsheet",
    "Excel add-in" : "Excel add-in",
    "Excel 2007 binary spreadsheet" : "Excel 2007 binary spreadsheet",
    "Excel spreadsheet template" : "Excel spreadsheet template",
    "Outlook Message" : "Outlook Message",
    "PowerPoint presentation" : "PowerPoint presentation",
    "PowerPoint add-in" : "PowerPoint add-in",
    "PowerPoint presentation template" : "PowerPoint presentation template",
    "Word document" : "Word document",
    "ODF formula" : "ODF formula",
    "ODG drawing" : "ODG drawing",
    "ODG drawing (Flat XML)" : "ODG drawing (Flat XML)",
    "ODG template" : "ODG template",
    "ODP presentation" : "ODP presentation",
    "ODP presentation (Flat XML)" : "ODP presentation (Flat XML)",
    "ODP template" : "ODP template",
    "ODS spreadsheet" : "ODS spreadsheet",
    "ODS spreadsheet (Flat XML)" : "ODS spreadsheet (Flat XML)",
    "ODS template" : "ODS template",
    "ODT document" : "ODT document",
    "ODT document (Flat XML)" : "ODT document (Flat XML)",
    "ODT template" : "ODT template",
    "PowerPoint 2007 presentation" : "PowerPoint 2007 presentation",
    "PowerPoint 2007 show" : "PowerPoint 2007 show",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007 presentation template",
    "Excel 2007 spreadsheet" : "Excel 2007 spreadsheet",
    "Excel 2007 spreadsheet template" : "Excel 2007 spreadsheet template",
    "Word 2007 document" : "Word 2007 document",
    "Word 2007 document template" : "Word 2007 document template",
    "Microsoft Visio document" : "Microsoft Visio document",
    "WordPerfect document" : "WordPerfect document",
    "7-zip archive" : "7-zip archive",
    "Blender scene" : "Blender scene",
    "Bzip2 archive" : "Bzip2 archive",
    "Debian package" : "Debian package",
    "FictionBook document" : "FictionBook document",
    "Unknown font" : "Unknown font",
    "Krita document" : "Krita document",
    "Mobipocket e-book" : "Mobipocket e-book",
    "Windows Installer package" : "Windows Installer package",
    "Perl script" : "Perl script",
    "PHP script" : "PHP script",
    "Tar archive" : "Tar archive",
    "XML document" : "XML document",
    "YAML document" : "YAML document",
    "Zip archive" : "Zip archive",
    "Zstandard archive" : "Zstandard archive",
    "AAC audio" : "AAC audio",
    "FLAC audio" : "FLAC audio",
    "MPEG-4 audio" : "MPEG-4 audio",
    "MP3 audio" : "MP3 audio",
    "Ogg audio" : "Ogg audio",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe standard Audio",
    "WebM audio" : "WebM audio",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
    "Windows BMP image" : "Windows BMP image",
    "Better Portable Graphics image" : "Better Portable Graphics image",
    "EMF image" : "EMF image",
    "GIF image" : "GIF image",
    "HEIC image" : "HEIC image",
    "HEIF image" : "HEIF image",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 image",
    "JPEG image" : "JPEG image",
    "PNG image" : "PNG image",
    "SVG image" : "SVG image",
    "Truevision Targa image" : "Truevision Targa image",
    "TIFF image" : "TIFF image",
    "WebP image" : "WebP image",
    "Digital raw image" : "Digital raw image",
    "Windows Icon" : "Windows Icon",
    "Email message" : "Email message",
    "VCS/ICS calendar" : "VCS/ICS calendar",
    "CSS stylesheet" : "CSS stylesheet",
    "CSV document" : "CSV document",
    "HTML document" : "HTML document",
    "Markdown document" : "Markdown document",
    "Org-mode file" : "Org-mode file",
    "Plain text document" : "Plain text document",
    "Rich Text document" : "Rich Text document",
    "Electronic business card" : "Electronic business card",
    "C++ source code" : "C++ source code",
    "LDIF address book" : "LDIF address book",
    "NFO document" : "NFO document",
    "PHP source" : "PHP source",
    "Python script" : "Python script",
    "ReStructuredText document" : "ReStructuredText document",
    "3GPP multimedia file" : "3GPP multimedia file",
    "MPEG video" : "MPEG video",
    "DV video" : "DV video",
    "MPEG-2 transport stream" : "MPEG-2 transport stream",
    "MPEG-4 video" : "MPEG-4 video",
    "Ogg video" : "Ogg video",
    "QuickTime video" : "QuickTime video",
    "WebM video" : "WebM video",
    "Flash video" : "Flash video",
    "Matroska video" : "Matroska video",
    "Windows Media video" : "Windows Media video",
    "AVI video" : "AVI video",
    "Done" : "Done",
    "Scan QR code to log in" : "Scan QR code to log in",
    "Use {productName} mobile client you want to connect to scan the code" : "Use {productName} mobile client you want to connect to scan the code",
    "Code will expire {timeCountdown} or after use" : "Code will expire {timeCountdown} or after use",
    "Applications menu" : "Applications menu",
    "Apps" : "Apps",
    "More apps" : "More apps",
    "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
    "No" : "No",
    "Yes" : "Yes",
    "App password" : "App password",
    "Grant access" : "Grant access",
    "The remote URL must include the user." : "The remote URL must include the user.",
    "Invalid remote URL." : "Invalid remote URL.",
    "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
    "Federated user" : "Federated user",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "Create share",
    "Direct link copied" : "Direct link copied",
    "Please copy the link manually:" : "Please copy the link manually:",
    "Custom date range" : "Custom date range",
    "Pick start date" : "Pick start date",
    "Pick end date" : "Pick end date",
    "Search in date range" : "Search in date range",
    "Search in current app" : "Search in current app",
    "Clear search" : "Clear search",
    "Search everywhere" : "Search everywhere",
    "Searching …" : "Searching …",
    "Start typing to search" : "Start typing to search",
    "Minimum search length is {minSearchLength} characters" : "Minimum search length is {minSearchLength} characters",
    "No matching results" : "No matching results",
    "Today" : "Today",
    "Last 7 days" : "Last 7 days",
    "Last 30 days" : "Last 30 days",
    "This year" : "This year",
    "Last year" : "Last year",
    "Between {startDate} and {endDate}" : "Between {startDate} and {endDate}",
    "Unified search" : "Unified search",
    "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
    "Places" : "Places",
    "Date" : "Date",
    "Search people" : "Search people",
    "People" : "People",
    "Filter in current view" : "Filter in current view",
    "Search connected services" : "Search connected services",
    "Results" : "Results",
    "Load more results" : "Load more results",
    "Search in" : "Search in",
    "Partial matches" : "Partial matches",
    "Log in" : "Log in",
    "Logging in …" : "Logging in …",
    "Log in to {productName}" : "Log in to {productName}",
    "Wrong login or password." : "Wrong login or password.",
    "This account is disabled" : "This account is disabled",
    "Too many incorrect login attempts. Please try again in 30 seconds." : "Too many incorrect login attempts. Please try again in 30 seconds.",
    "Account name or email" : "Account name or email",
    "Account name" : "Account name",
    "Server side authentication failed!" : "Server side authentication failed!",
    "Please contact your administrator." : "Please contact your administrator.",
    "Session error" : "Session error",
    "It appears your session token has expired, please refresh the page and try again." : "It appears your session token has expired, please refresh the page and try again.",
    "An internal error occurred." : "An internal error occurred.",
    "Please try again or contact your administrator." : "Please try again or contact your administrator.",
    "Password" : "Password",
    "Remember me" : "Remember me",
    "Log in with a device" : "Log in with a device",
    "Login or email" : "Login or email",
    "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
    "Your connection is not secure" : "Your connection is not secure",
    "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
    "Browser not supported" : "Browser not supported",
    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
    "Reset password" : "Reset password",
    "Back to login" : "Back to login",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help.",
    "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
    "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
    "New password" : "New password",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
    "I know what I'm doing" : "I know what I'm doing",
    "Resetting password" : "Resetting password",
    "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
    "Distraction free note taking app." : "Distraction free note taking app.",
    "Recommended apps" : "Recommended apps",
    "Loading apps …" : "Loading apps …",
    "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
    "App download or installation failed" : "App download or installation failed",
    "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
    "Cannot install this app" : "Cannot install this app",
    "Skip" : "Skip",
    "Installing apps …" : "Installing apps …",
    "Install recommended apps" : "Install recommended apps",
    "Online" : "Online",
    "Away" : "Away",
    "Busy" : "Busy",
    "Do not disturb" : "Do not disturb",
    "Mute all notifications" : "Mute all notifications",
    "Invisible" : "Invisible",
    "Appear offline" : "Appear offline",
    "Avatar of {displayName}" : "Avatar of {displayName}",
    "Settings menu" : "Settings menu",
    "Loading your contacts …" : "Loading your contacts …",
    "Looking for {term} …" : "Looking for {term} …",
    "Search contacts" : "Search contacts",
    "Filter by team" : "Filter by team",
    "All teams" : "All teams",
    "Search contacts in team {team}" : "Search contacts in team {team}",
    "Search contacts …" : "Search contacts …",
    "Reset search" : "Reset search",
    "Could not load your contacts" : "Could not load your contacts",
    "No contacts found" : "No contacts found",
    "Contacts list" : "Contacts list",
    "Show all contacts" : "Show all contacts",
    "Install the Contacts app" : "Install the Contacts app",
    "Search" : "Search",
    "No results for {query}" : "No results for {query}",
    "Press Enter to start searching" : "Press Enter to start searching",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
    "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
    "Search for {name} only" : "Search for {name} only",
    "Loading more results …" : "Loading more results …",
    "Forgot password?" : "Forgot password?",
    "Back to login form" : "Back to login form",
    "Back" : "Back",
    "Login form is disabled." : "Login form is disabled.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "The Nextcloud login form is disabled. Use another login option if available or contact your administration.",
    "Connect to your account" : "Connect to your account",
    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Please log in before granting \"{client}\" access to your {instanceName} account.",
    "Security warning" : "Security warning",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
    "Log in using password" : "Log in using password",
    "Alternative log in using app password" : "Alternative log in using app password",
    "Account connected" : "Account connected",
    "Your client should now be connected!" : "Your client should now be connected!",
    "You can close this window." : "You can close this window.",
    "Account access" : "Account access",
    "Currently logged in as {userDisplayName} ({userId})." : "Currently logged in as {userDisplayName} ({userId}).",
    "You are about to grant \"{client}\" access to your {instanceName} account." : "You are about to grant \"{client}\" access to your {instanceName} account.",
    "More actions" : "More actions",
    "User menu" : "User menu",
    "Your guest name: {user}" : "Your guest name: {user}",
    "You are currently not identified." : "You are currently not identified.",
    "Set public name" : "Set public name",
    "Change public name" : "Change public name",
    "This share is password-protected" : "This share is password-protected",
    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
    "Submit" : "Submit",
    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
    "Password sent!" : "Password sent!",
    "You are not authorized to request a password for this share" : "You are not authorised to request a password for this share",
    "Email address" : "Email address",
    "Request password" : "Request password",
    "Forgot password" : "Forgot password",
    "Password is too weak" : "Password is too weak",
    "Password is weak" : "Password is weak",
    "Password is average" : "Password is average",
    "Password is strong" : "Password is strong",
    "Password is very strong" : "Password is very strong",
    "Password is extremely strong" : "Password is extremely strong",
    "Unknown password strength" : "Unknown password strength",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}",
    "Autoconfig file detected" : "Autoconfig file detected",
    "The setup form below is pre-filled with the values from the config file." : "The setup form below is pre-filled with the values from the config file.",
    "Create administration account" : "Create administration account",
    "Administration account name" : "Administration account name",
    "Administration account password" : "Administration account password",
    "Storage & database" : "Storage & database",
    "Data folder" : "Data folder",
    "Database configuration" : "Database configuration",
    "Database type" : "Database type",
    "Only {firstAndOnlyDatabase} is available." : "Only {firstAndOnlyDatabase} is available.",
    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
    "For more details check out the documentation." : "For more details check out the documentation.",
    "Performance warning" : "Performance warning",
    "You chose SQLite as database." : "You chose SQLite as database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
    "Database connection" : "Database connection",
    "Database user" : "Database user",
    "Database password" : "Database password",
    "Database name" : "Database name",
    "Database tablespace" : "Database tablespace",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
    "Database host" : "Database host",
    "localhost" : "localhost",
    "Installing …" : "Installing …",
    "Install" : "Install",
    "Need help?" : "Need help?",
    "See the documentation" : "See the documentation",
    "{name} version {version} and above" : "{name} version {version} and above",
    "This browser is not supported" : "This browser is not supported",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
    "Continue with this unsupported browser" : "Continue with this unsupported browser",
    "Supported versions" : "Supported versions",
    "The update completed with warnings. Please check the details for more information." : "The update completed with warnings. Please check the details for more information.",
    "The update completed successfully." : "The update completed successfully.",
    "Preparing update…" : "Preparing update…",
    "You will be redirected to {productName} in {count} seconds." : "You will be redirected to {productName} in {count} seconds.",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
    "App update required" : "App update required",
    "{productName} will be updated to version {version}" : "{productName} will be updated to version {version}",
    "The theme {oldTheme} has been disabled." : "The theme {oldTheme} has been disabled.",
    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
    "Incompatible apps" : "Incompatible apps",
    "These apps will be updated:" : "These apps will be updated:",
    "Apps to update" : "Apps to update",
    "{app} from {oldVersion} to {version}" : "{app} from {oldVersion} to {version}",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
    "Start update" : "Start update",
    "Continue to {productName}" : "Continue to {productName}",
    "Update to {version}" : "Update to {version}",
    "Hide details" : "Hide details",
    "Show details" : "Show details",
    "Update details" : "Update details",
    "Update needed" : "Update needed",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Please use the command line updater because you have a big instance with more than 50 accounts.",
    "Documentation" : "Documentation",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
    "Search {types} …" : "Search {types} …",
    "Choose {file}" : "Choose {file}",
    "Choose" : "Choose",
    "Copy to {target}" : "Copy to {target}",
    "Copy" : "Copy",
    "Move to {target}" : "Move to {target}",
    "Move" : "Move",
    "OK" : "OK",
    "read-only" : "read-only",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} file conflict","{count} file conflicts"],
    "One file conflict" : "One file conflict",
    "New Files" : "New Files",
    "Already existing files" : "Already existing files",
    "Which files do you want to keep?" : "Which files do you wish to keep?",
    "If you select both versions, the copied file will have a number added to its name." : "If you select both versions, the copied file will have a number added to its name.",
    "Cancel" : "Cancel",
    "Continue" : "Continue",
    "(all selected)" : "(all selected)",
    "({count} selected)" : "({count} selected)",
    "Error loading file exists template" : "Error loading file exists template",
    "Saving …" : "Saving …",
    "Groups" : "Groups",
    "Group list is empty" : "Group list is empty",
    "Unable to retrieve the group list" : "Unable to retrieve the group list",
    "seconds ago" : "seconds ago",
    "Add to a project" : "Add to a project",
    "Rename project" : "Rename project",
    "Failed to rename the project" : "Failed to rename the project",
    "Failed to create a project" : "Failed to create a project",
    "Failed to add the item to the project" : "Failed to add the item to the project",
    "Connect items to a project to make them easier to find" : "Connect items to a project to make them easier to find",
    "Type to search for existing projects" : "Type to search for existing projects",
    "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialogue",
    "Email length is at max (255)" : "Email length is at max (255)",
    "Clipboard not available, please copy manually" : "Clipboard not available, please copy manually",
    "Personal" : "Personal",
    "Accounts" : "Accounts",
    "Admin" : "Admin",
    "Help" : "Help",
    "Access forbidden" : "Access denied",
    "You are not allowed to access this page." : "You are not allowed to access this page.",
    "Back to %s" : "Back to %s",
    "Page not found" : "Page not found",
    "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
    "Too many requests" : "Too many requests",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "Error",
    "Internal Server Error" : "Internal Server Error",
    "The server was unable to complete your request." : "The server was unable to complete your request.",
    "If this happens again, please send the technical details below to the server administrator." : "If this happens again, please send the technical details below to the server administrator.",
    "More details can be found in the server log." : "More details can be found in the server log.",
    "For more details see the documentation ↗." : "For more details see the documentation ↗.",
    "Technical details" : "Technical details",
    "Remote Address: %s" : "Remote Address: %s",
    "Request ID: %s" : "Request ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Message: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Line: %s",
    "Trace" : "Trace",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
    "Skip to main content" : "Skip to main content",
    "Skip to navigation of app" : "Skip to navigation of app",
    "Go to %s" : "Go to %s",
    "Get your own free account" : "Get your own free account",
    "Previous" : "Previous",
    "Two-factor authentication" : "Two-factor authentication",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Enhanced security is enabled for your account. Choose a second factor for authentication:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Could not load at least one of your enabled two-factor auth methods. Please contact your admin.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication.",
    "Set up two-factor authentication" : "Set up two-factor authentication",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance.",
    "Use backup code" : "Use backup code",
    "Cancel login" : "Cancel login",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Enhanced security is enforced for your account. Choose which provider to set up:",
    "Error while validating your second factor" : "Error while validating your second factor",
    "Access through untrusted domain" : "Access through untrusted domain",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Further information how to configure this can be found in the %1$sdocumentation%2$s.",
    "Maintenance mode" : "Maintenance mode",
    "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
    "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
    "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
    "unknown text" : "unknown text",
    "Hello world!" : "Hello world!",
    "sunny" : "sunny",
    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
    "Hello {name}" : "Hello {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
    "new" : "new",
    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
    "An error occurred." : "An error occurred.",
    "Please reload the page." : "Please reload the page.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
    "Direct link copied to clipboard" : "Direct link copied to clipboard",
    "Searching …" : "Searching …",
    "Logging in …" : "Logging in …",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
    "Loading apps …" : "Loading apps …",
    "Installing apps …" : "Installing apps …",
    "Loading your contacts …" : "Loading your contacts …",
    "Looking for {term} …" : "Looking for {term} …",
    "Search contacts …" : "Search contacts …",
    "Loading more results …" : "Loading more results …",
    "Search {types} …" : "Search {types} …",
    "Saving …" : "Saving …",
    "Connection to server lost" : "Connection to server lost",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
    "New in" : "New in",
    "View changelog" : "View changelog",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "No action available" : "No action available",
    "Error fetching contact actions" : "Error fetching contact actions",
    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
    "Restricted" : "Restricted",
    "Delete" : "Delete",
    "Rename" : "Rename",
    "Collaborative tags" : "Collaborative tags",
    "No tags found" : "No tags found",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Create an admin account</strong>",
    "New admin account name" : "New admin account name",
    "New admin password" : "New admin password",
    "Show password" : "Show password",
    "Toggle password visibility" : "Toggle password visibility",
    "Configure the database" : "Configure the database",
    "Only %s is available." : "Only %s is available.",
    "Database account" : "Database account",
    "Installing …" : "Installing …",
    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
    "The following apps will be updated:" : "The following apps will be updated:",
    "The theme %s has been disabled." : "The theme %s has been disabled.",
    "Detailed logs" : "Detailed logs",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>."
},
"nplurals=2; plural=(n != 1);");
